aboutsummaryrefslogtreecommitdiff
path: root/gcc/cp/search.c
diff options
context:
space:
mode:
authorMike Stump <mrs@gcc.gnu.org>1994-11-29 00:59:16 +0000
committerMike Stump <mrs@gcc.gnu.org>1994-11-29 00:59:16 +0000
commitdb5ae43ff2ce49f1cbe66a0e16f4e079b702580b (patch)
tree572fd369f71d068ba440682b16fe5848cd15d1cf /gcc/cp/search.c
parentc7a7ac465ec752e3c21494ff810e95e851f36ac3 (diff)
downloadgcc-db5ae43ff2ce49f1cbe66a0e16f4e079b702580b.zip
gcc-db5ae43ff2ce49f1cbe66a0e16f4e079b702580b.tar.gz
gcc-db5ae43ff2ce49f1cbe66a0e16f4e079b702580b.tar.bz2
49th Cygnus<->FSF merge
From-SVN: r8570
Diffstat (limited to 'gcc/cp/search.c')
-rw-r--r--gcc/cp/search.c11
1 files changed, 4 insertions, 7 deletions
diff --git a/gcc/cp/search.c b/gcc/cp/search.c
index 7f6af72..9fb8e63 100644
--- a/gcc/cp/search.c
+++ b/gcc/cp/search.c
@@ -377,8 +377,8 @@ pop_memoized_context (use_old)
type_stack = (struct type_level *)type_stack->base.prev;
}
-#if 0 /* unused */
/* This is the newer recursive depth first search routine. */
+#if 0 /* unused */
/* Return non-zero if PARENT is directly derived from TYPE. By directly
we mean it's only one step up the inheritance lattice. We check this
by walking horizontally across the types that TYPE directly inherits
@@ -1995,12 +1995,9 @@ get_abstract_virtuals_1 (binfo, do_self, abstract_virtuals)
/* Should we use something besides CLASSTYPE_VFIELDS? */
if (do_self && CLASSTYPE_VFIELDS (BINFO_TYPE (binfo)))
{
+ /* Get around first entry reserved for RTTI. */
tree tmp = TREE_CHAIN (BINFO_VIRTUALS (binfo));
- /* Get around dossier entry if there is one. */
- if (flag_dossier)
- tmp = TREE_CHAIN (tmp);
-
while (tmp)
{
tree base_pfn = FNADDR_FROM_VTABLE_ENTRY (TREE_VALUE (tmp));
@@ -2417,10 +2414,10 @@ dfs_init_vbase_pointers (binfo)
CLEAR_BINFO_VTABLE_PATH_MARKED (binfo);
/* If there is a dossier, it is the first field, though perhaps from
the base class. Otherwise, the first fields are virtual base class
pointer fields. */
- if (CLASSTYPE_DOSSIER (type) && VFIELD_NAME_P (DECL_NAME (fields)))
+ if (CLASSTYPE_RTTI (type) && VFIELD_NAME_P (DECL_NAME (fields)))
/* Get past vtable for the object. */
fields = TREE_CHAIN (fields);
@@ -2417,10 +2414,10 @@ dfs_init_vbase_pointers (binfo)
CLEAR_BINFO_VTABLE_PATH_MARKED (binfo);
- /* If there is a dossier, it is the first field, though perhaps from
+ /* If there is a rtti, it is the first field, though perhaps from
the base class. Otherwise, the first fields are virtual base class
pointer fields. */